@@ -1,6 +1,8 @@
 //! `dsrs` contains bindings for a subset of [Apache DataSketches](https://github.com/apache/datasketches-cpp).
 
 mod bridge;
+pub mod counters;
+pub mod stream_reducer;
 mod wrapper;
 
 pub use wrapper::CpcSketch;
